import 'package:cpt_services/modules/services_detail/services_detail_page.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/widget_export.dart';
import 'package:cs_resources/generated/assets.dart';

import '../../../router/page/services_page_router.dart';
import './services_list_vm.dart';

@RoutePage()
class ServicesListPage extends HookConsumerWidget {
  const ServicesListPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const ServicesListPageRoute());
    } else {
      appRouter.push(const ServicesListPageRoute());
    }
  }

  Widget _buildItemLeftSection(BuildContext context, WidgetRef ref, item, _vm) {
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        ClipRRect(
            borderRadius: BorderRadius.circular(10.0),
            child: MyAssetImage(
              item['price'],
              width: 83,
              height: 58,
            )),
      ],
    );
  }

  Widget _buildItemRightSection(
      BuildContext context, WidgetRef ref, item, _vm) {
        final num = item['num'];
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      mainAxisAlignment: MainAxisAlignment.center,
      children: [
        Text(
          item['title'],
          style: const TextStyle(
              fontSize: 16.0,
              color: Colors.black,
              fontWeight: FontWeight.w500), // 设置字体大小
        ).marginOnly(bottom: 10),
        Row(
            children: [
              SizedBox(
                width: 100,
                height: 16,
                child: ListView.builder(
                scrollDirection: Axis.horizontal,
                itemCount: 5,
                itemBuilder: (context, index) {
                  return MyAssetImage(
                    item['num']>= index+1?Assets.serviceServiceScoreYes: Assets.serviceServiceScoreNo,
                    width: 16.5,
                    height: 15.5,
                  ).marginOnly(right: 4);
                }),
              ),
              Text(
                "$num",
                style: const TextStyle(
                    fontSize: 16.0,
                    color: Colors.black,
                    fontWeight: FontWeight.w500), // 设置字体大小
              ).marginOnly(left: 5),
            ]),
      ],
    );
  }

  // listitem
  Widget _buildSaleItem(BuildContext context, WidgetRef ref, item, _vm) {
    return Container(
      decoration: const BoxDecoration(
        color: Colors.white,
        borderRadius: BorderRadius.all(Radius.circular(6.0)),
        boxShadow: [
          BoxShadow(color: Color.fromRGBO(184, 191, 217, 0.3), blurRadius: 6)
        ],
      ),
      child: Column(
        children: [
          Container(
            width: MediaQuery.of(context).size.width - 30,
            height: 85,
            child: Row(
              crossAxisAlignment: CrossAxisAlignment.start,
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                _buildItemLeftSection(context, ref, item, _vm)
                    .marginOnly(right: 20),
                _buildItemRightSection(context, ref, item, _vm),
              ],
            ).paddingOnly(left: 15, right: 15),
          ).constrained(
            minHeight: 85,
          ),
        ],
      ).onTap(() {
        // 去详情
        // _vm.goNewsDetail(item['title']);
        Navigator.push(
          context,
          MaterialPageRoute(builder: (context) => const ServicesDetailPage()),
        );
      }),
    ).marginOnly(left: 15, bottom: 15, right: 15);
  }

  // list
  Widget _buildSaleList(BuildContext context, WidgetRef ref, _vm) {
    List itemsList = _vm.state.list.toList();
    return ListView.builder(
      itemCount: itemsList.length,
      itemBuilder: (context, index) {
        return _buildSaleItem(context, ref, itemsList[index], _vm);
      },
    );
  }

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final _vm = ref.read(servicesListVmProvider.notifier);

    return Scaffold(
      appBar: MyAppBar.appBar(
        context,
        "Part-Time Cleaning",
        backgroundColor: context.appColors.whiteBG,
      ),
      body: Container(
          child: EasyRefresh(
        // 上拉加载
        onLoad: () async {
          Log.d("----onLoad");
          _vm.onLoadData();
        },
        // 下拉刷新
        onRefresh: () async {
          Log.d("----onRefresh");
          _vm.refreshListData();
        },
        child: Container(
            color: ColorUtils.string2Color('#F2F3F6'),
            padding: const EdgeInsets.only(top: 15),
            child: _buildSaleList(context, ref, _vm)),
      )),
    );
  }
}
